@@ -1,4 +1,4 @@
-import os, random, sys, cv2, time, csv, pickle, re, pkg_resources
+import os, random, sys, time, csv, pickle, re, pkg_resources
 os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 from tkinter import StringVar, DoubleVar, Tk, Label, Entry, Button, OptionMenu, Checkbutton, Message, Menu, IntVar, Scale, HORIZONTAL
 from tkinter.ttk import Progressbar, Separator, Combobox
@@ -24,6 +24,7 @@ except:
 	from pyanthem_vars import *
 from git import Repo
 from google_drive_downloader import GoogleDriveDownloader as gdd
+import subprocess as sp
 
 def AE_download():
 	'''
@@ -540,21 +541,47 @@ class GUI(Tk):
 		'''
 		Writes video file using self.data['H_pp'] using opencv
 		'''
+		import PIL.Image as Image
 		if self.check_data_and_save_path():		
 			if not self.display:
 				self.process_H_W()
 			if self.display:
 				self.dump_config()
-			fourcc = cv2.VideoWriter_fourcc(*'mp4v')
-			out = cv2.VideoWriter(os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mp4', fourcc, self.cfg['fr']*self.cfg['speed']/100, tuple(self.data['W_shape'][::-1][1:]),True)
+			fn_vid = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mp4'
+			v_shape = self.data['W_shape'][::-1][1:]
+			command = [ 'ffmpeg',
+				'-y',
+				'-f', 'rawvideo',
+				'-vcodec','mjpeg',
+				'-s', '{}x{}'.format(v_shape[0],v_shape[1]),
+				'-pix_fmt', 'rgb24',
+				'-r', str(self.cfg['fr']),
+				'-i', '-', # The input comes from a pipe
+				'-an', # Tells FFMPEG not to expect any audio
+				'-vcodec', 'mpeg4',
+				fn_vid]
+			pipe = sp.Popen( command, stdin=sp.PIPE, stderr=sp.PIPE)
 			nframes = len(self.data['H_pp'].T)
 			for i in range(nframes):
 				frame = (self.data['W_pp']@np.diag(self.data['H_pp'][:,i])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8')
-				out.write(cv2.cvtColor(frame, cv2.COLOR_RGB2BGR))
-				if self.display:
-					self.status['text'] = f'Status: writing video file, {i+1} out of {nframes} frames written'
+				im = Image.fromarray(frame)
+				im.save(pipe.stdin, 'JPEG')
+				pipe.stdin.write(frame.tostring())
+				if self.display and i%10==0:
+					self.status['text'] = f'Status: writing video file, {i} out of {nframes} frames written'
 					self.update()
-			out.release()
+			pipe.stdin.close()
+			pipe.wait()
+			#fourcc = cv2.VideoWriter_fourcc(*'mp4v')
+			#out = cv2.VideoWriter(, fourcc, self.cfg['fr']*self.cfg['speed']/100, tuple(self.data['W_shape'][::-1][1:]),True)
+			#
+			#for i in range(nframes):
+			#	frame = (self.data['W_pp']@np.diag(self.data['H_pp'][:,i])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8')
+			#	out.write(cv2.cvtColor(frame, cv2.COLOR_RGB2BGR))
+			#	if self.display:
+			#		self.status['text'] = f'Status: writing video file, {i+1} out of {nframes} frames written'
+			#		self.update()
+			#out.release()
 			if self.display:
 				self.status['text'] = f'Status: video file written to {self.cfg["save_path"]}'
 			else:
